@@ -29,7 +29,7 @@ def add_lengths(g):
     return g
 
 ##########################################################
-def get_largest_component_from_file(graphpath, undirect=True, simplify=True):
+def simplify_graphml(graphpath, directed=True, simplify=True):
     """Get largest connected component from @graphatph and add weights
     According to the params @undirected, @simplify, convert to
     undirected and/or remove multiple edges and self-loops.
@@ -37,7 +37,7 @@ def get_largest_component_from_file(graphpath, undirect=True, simplify=True):
 
     g = igraph.Graph.Read(graphpath)
     if simplify: g.simplify(combine_edges='first')
-    if undirect: g.to_undirected()
+    if not directed: g.to_undirected()
     g = g.components(mode='weak').giant()
 
     if ('x' in g.vertex_attributes()) or ('lon' in g.vertex_attributes()):
